/****************************************************************************
** Meta object code from reading C++ file 'WeatherPlugin.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../../../marble-26.08.0/src/plugins/render/weather/WeatherPlugin.h"
#include <QtCore/qmetatype.h>
#include <QtCore/qplugin.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'WeatherPlugin.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN6Marble13WeatherPluginE_t {};
} // unnamed namespace

template <> constexpr inline auto Marble::WeatherPlugin::qt_create_metaobjectdata<qt_meta_tag_ZN6Marble13WeatherPluginE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "Marble::WeatherPlugin",
        "changedSettings",
        "",
        "readSettings",
        "writeSettings",
        "updateItemSettings",
        "favoriteItemsChanged",
        "favoriteItems"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'changedSettings'
        QtMocHelpers::SignalData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'readSettings'
        QtMocHelpers::SlotData<void()>(3, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'writeSettings'
        QtMocHelpers::SlotData<void()>(4, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'updateItemSettings'
        QtMocHelpers::SlotData<void()>(5, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'favoriteItemsChanged'
        QtMocHelpers::SlotData<void(const QStringList &)>(6, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QStringList, 7 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<WeatherPlugin, qt_meta_tag_ZN6Marble13WeatherPluginE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject Marble::WeatherPlugin::staticMetaObject = { {
    QMetaObject::SuperData::link<AbstractDataPlugin::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN6Marble13WeatherPluginE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN6Marble13WeatherPluginE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN6Marble13WeatherPluginE_t>.metaTypes,
    nullptr
} };

void Marble::WeatherPlugin::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<WeatherPlugin *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->changedSettings(); break;
        case 1: _t->readSettings(); break;
        case 2: _t->writeSettings(); break;
        case 3: _t->updateItemSettings(); break;
        case 4: _t->favoriteItemsChanged((*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (WeatherPlugin::*)()>(_a, &WeatherPlugin::changedSettings, 0))
            return;
    }
}

const QMetaObject *Marble::WeatherPlugin::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Marble::WeatherPlugin::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN6Marble13WeatherPluginE_t>.strings))
        return static_cast<void*>(this);
    if (!strcmp(_clname, "DialogConfigurationInterface"))
        return static_cast< DialogConfigurationInterface*>(this);
    if (!strcmp(_clname, "org.kde.Marble.RenderPluginInterface/1.09"))
        return static_cast< Marble::RenderPluginInterface*>(this);
    if (!strcmp(_clname, "org.kde.Marble.DialogConfigurationInterface/1.0"))
        return static_cast< Marble::DialogConfigurationInterface*>(this);
    return AbstractDataPlugin::qt_metacast(_clname);
}

int Marble::WeatherPlugin::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = AbstractDataPlugin::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 5)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 5;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 5)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 5;
    }
    return _id;
}

// SIGNAL 0
void Marble::WeatherPlugin::changedSettings()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}
using namespace Marble;

#ifdef QT_MOC_EXPORT_PLUGIN_V2
static constexpr unsigned char qt_pluginMetaDataV2_WeatherPlugin[] = {
    0xbf, 
    // "IID"
    0x02,  0x78,  0x1c,  'o',  'r',  'g',  '.',  'k', 
    'd',  'e',  '.',  'm',  'a',  'r',  'b',  'l', 
    'e',  '.',  'W',  'e',  'a',  't',  'h',  'e', 
    'r',  'P',  'l',  'u',  'g',  'i',  'n', 
    // "className"
    0x03,  0x6d,  'W',  'e',  'a',  't',  'h',  'e', 
    'r',  'P',  'l',  'u',  'g',  'i',  'n', 
    0xff, 
};
QT_MOC_EXPORT_PLUGIN_V2(Marble::WeatherPlugin, WeatherPlugin, qt_pluginMetaDataV2_WeatherPlugin)
#else
QT_PLUGIN_METADATA_SECTION
Q_CONSTINIT static constexpr unsigned char qt_pluginMetaData_WeatherPlugin[] = {
    'Q', 'T', 'M', 'E', 'T', 'A', 'D', 'A', 'T', 'A', ' ', '!',
    // metadata version, Qt version, architectural requirements
    0, QT_VERSION_MAJOR, QT_VERSION_MINOR, qPluginArchRequirements(),
    0xbf, 
    // "IID"
    0x02,  0x78,  0x1c,  'o',  'r',  'g',  '.',  'k', 
    'd',  'e',  '.',  'm',  'a',  'r',  'b',  'l', 
    'e',  '.',  'W',  'e',  'a',  't',  'h',  'e', 
    'r',  'P',  'l',  'u',  'g',  'i',  'n', 
    // "className"
    0x03,  0x6d,  'W',  'e',  'a',  't',  'h',  'e', 
    'r',  'P',  'l',  'u',  'g',  'i',  'n', 
    0xff, 
};
QT_MOC_EXPORT_PLUGIN(Marble::WeatherPlugin, WeatherPlugin)
#endif  // QT_MOC_EXPORT_PLUGIN_V2

QT_WARNING_POP
